// Copyright 2003 Nokia Corporation.
//
// THIS SOURCE CODE IS PROVIDED 'AS IS', WITH NO WARRANTIES WHATSOEVER,
// EXPRESS OR IMPLIED, INCLUDING ANY WARRANTY OF MERCHANTABILITY, FITNESS
// FOR ANY PARTICULAR PURPOSE, OR ARISING FROM A COURSE OF DEALING, USAGE
// OR TRADE PRACTICE, RELATING TO THE SOURCE CODE OR ANY WARRANTY OTHERWISE
// ARISING OUT OF ANY PROPOSAL, SPECIFICATION, OR SAMPLE AND WITH NO
// OBLIGATION OF NOKIA TO PROVIDE THE LICENSEE WITH ANY MAINTENANCE OR
// SUPPORT. FURTHERMORE, NOKIA MAKES NO WARRANTY THAT EXERCISE OF THE
// RIGHTS GRANTED HEREUNDER DOES NOT INFRINGE OR MAY NOT CAUSE INFRINGEMENT
// OF ANY PATENT OR OTHER INTELLECTUAL PROPERTY RIGHTS OWNED OR CONTROLLED
// BY THIRD PARTIES
//
// Furthermore, information provided in this source code is preliminary,
// and may be changed substantially prior to final release. Nokia Corporation
// retains the right to make changes to this source code at
// any time, without notice. This source code is provided for informational
// purposes only.
//
// Nokia and Nokia Connecting People are registered trademarks of Nokia
// Corporation.
// Java and all Java-based marks are trademarks or registered trademarks of
// Sun Microsystems, Inc.
// Other product and company names mentioned herein may be trademarks or
// trade names of their respective owners.
//
// A non-exclusive, non-transferable, worldwide, limited license is hereby
// granted to the Licensee to download, print, reproduce and modify the
// source code. The licensee has the right to market, sell, distribute and
// make available the source code in original or modified form only when
// incorporated into the programs developed by the Licensee. No other
// license, express or implied, by estoppel or otherwise, to any other
// intellectual property rights is granted herein.
import javax.microedition.lcdui.*;
import javax.microedition.m3g.*;

class MenuList
  extends List
  implements CommandListener
{
  private final Maze3DMIDlet midlet;
  private boolean gameStarted = false;

  MenuList(Maze3DMIDlet midlet, boolean apiAvailable)
  {
    super("Maze3D", List.IMPLICIT);

    this.midlet = midlet;

    setFitPolicy(List.TEXT_WRAP_ON);

    // in case the 3D API is not available
    if (apiAvailable)
    {
      append("New Game", null);
      append("3D Properties", null);
    }
    // add an exit command
    addCommand(new Command("Exit", Command.EXIT, 0));
    setCommandListener(this);
  }

  public void commandAction(Command command, Displayable displayable)
  {
    if (command == List.SELECT_COMMAND)
    {
      int index = getSelectedIndex();
      switch (index)
      {
        case 0:
          //  new game
          midlet.newGame();
          // add more commands the first time the game runs
          if (!gameStarted)
          {
            insert(1, "Top view", null);
            addCommand(new Command("Back", Command.BACK, 0));
            gameStarted = true;
          }
          break;
        case 1:
          if (gameStarted)
          {
            midlet.switchView();
          }
          else
          {
            midlet.show3DProperties();
          }
          break;
        case 2:
          midlet.show3DProperties();
          break;
      }
    }
    else if (command.getCommandType() == Command.BACK)
    {
      midlet.showMain();
    }
    else if (command.getCommandType() == Command.EXIT)
    {
      midlet.quitApp();
    }
  }


  void viewSwitched()
  {
    // switch the labels for normal/top view
    if (getString(1).equals("Top view"))
    {
      set(1, "Normal view", null);
    }
    else
    {
      set(1, "Top view", null);
    }
  }
}

